package com.persagy.mq;

import org.springframework.amqp.core.Binding;
import org.springframework.amqp.core.BindingBuilder;
import org.springframework.amqp.core.Queue;
import org.springframework.amqp.core.TopicExchange;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.env.Environment;

/**
 * RabbitConfig
 * 
 * @author gaoyu
 *
 */
@Configuration
public class RabbitConfig {
	/**
	 * 交换机
	 */
	public static final String exchange = "exchange-msg-service";
	public static final String exchangeAlarm = "exchange-alarm-service";
	public static final String alarmMsgRoutingKey = "alarm-msg-routing-key";
	private static final String alarmMsgRouting = "-alarm-data-routing-key";
	private final String alarmDataQueue = "-alarm-data-queue";

	@Bean
	public TopicExchange exchange() {
		return new TopicExchange(exchange);
	}

	@Bean
	public Queue alarmDataQueue(Environment environment) {
		return new Queue(environment.getProperty("group.code") + alarmDataQueue, true);
	}

	@Bean
	public Binding alarmObjBinding(Environment environment) {
		return BindingBuilder.bind(alarmDataQueue(environment)).to(exchange())
				.with(environment.getProperty("group.code") + alarmMsgRouting);
	}
}
